import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:windows_nt_user/windows_nt_user.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _windowsUsername = 'Unknown';

  @override
  void initState() {
    super.initState();
    initPlatformState();
  }

  // WindowsUser messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    String windowsUsername;
    // WindowsUser messages may fail, so we use a try/catch WindowsUserException.
    // We also handle the message potentially returning null.
    try {
      windowsUsername =
          await WindowsNtUser.getNTUser ?? 'Unknown UserID version';
    } on PlatformException {
      windowsUsername = 'Failed to get Username.';
    }

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _windowsUsername = windowsUsername;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: Text('Running on: $_windowsUsername\n'),
        ),
      ),
    );
  }
}
